# Virtual Coaching for Smoking Cessation: What are Users Preference in Ethical Principles for Human Feedback Allocation
This file provides information on how to reproduce our analyses for the paper "Virtual Coaching for Smoking Cessation: What are Users Preference in Ethical Principles for Human Feedback Allocation" by Glebs Labunskis.
Go to https://doi.org/10.17605/OSF.IO/78CNR to find the original data used for this analysis.
**Author**: Glebs Labunskis \
**Date**: June 2024

## Contents of the repository
```
Data
│
└───correlations
│    └───closed question pb calculation
│        └───coding
│            │   main.py
│            │   point_biserial.py
│        └───Outputs
│    └───dropout pb calculation
│        └───coding
│            │   main.py
│            │   pb_application
│            │   point_biserial.py
│        └───Data
│            └───Theme_binary
│                │   appreciate.csv
│                │   chance.csv
│                │   equal.csv
│                │   struggle.csv
│        └───Outputs
│    └───humanstate pb calculation
│        └───coding
│            │   main.py
│            │   pb_application
│            │   point_biserial.py
│        └───Data
│            └───Theme_binary
│                │   appreciate.csv
│                │   chance.csv
│                │   equal.csv
│                │   struggle.csv
│        └───Outputs
│    └─── README.md
│
└───results
│   │   Cohen_kappa_adjusted.xlsx
│   │   Cohen_kappa_non_adjusted.xlsx
│   │   mind map of themes.png
│   │   point_biserial_results_closed_q.csv
│   │   point_biserial_results_dropout.xlsx
│   │   point_biserial_results_humanstate.xlsx
│   README.md
```

## Data
All data has been anonymized and there is an identifier `rand_id` that is used to distinguish between people.

## Explanation of folders
- `correlations`: folder with all data related to correlations calculations. These calculations are used during the quantitative analysis.
- `closed question pb calculation`: folder with all data related to calculating the Point-Biserial correlation coefficient between the closed question data and themes.
- `dropout pb calculation`: folder with all data related to calculating the Point-Biserial correlation coefficient between the dropout question in session data and themes. These calculations are used during the quantitative analysis.
- `humanstate pb calculation`: folder with all data related to calculating the Point-Biserial correlation coefficient between the state_humansupport question in session data and themes. These calculations are used during the quantitative analysis.
- `Theme_binary`: folders containing tables for each of the themes. Used in the calculations of the correlation. 
- `results`: a folder containing all the results obtained throughout the research.

## Explanation of files:
- `README.md` - files explaining the usage of the repository.
- `point_biserial.py` - code responsible for calculating the Point-Biserial coefficient.
- `main.py` - code to be run for getting the results.
- `mind map of themes.png` - the mind map presenting the final themes.

## Running the main.py files:
1. Add the path to the desired data (described and pointed in the file).
2. Run the main file. 
3. Results are printed in the terminal and written to Outputs, into a csv file.

## Table explanation:
- `appreciate.csv`: A table with two columns: first is a `rand_id` - identifier and the second is a binary representation of whether the response of this participant was coded as an "Appreciate the most" theme.
- `chance.csv`: A table with two columns: first is a `rand_id` - identifier and the second is a binary representation of whether the response of this participant was coded as an "Increasing chances the most" theme.
- `equal.csv`: A table with two columns: first is a `rand_id` - identifier and the second is a binary representation of whether the response of this participant was coded as an "Equal the most" theme.
- `struggle.csv`: A table with two columns: first is a `rand_id` - identifier and the second is a binary representation of whether the response of this participant was coded as a "Struggling the most" theme.
- `Cohen_kappa_adjusted.xlsx`: The final version of coded responses and Cohen Kappa calculations (after revising the themes and removing "No label" from Cohen Kappa calculations):
	- Sheet 1: A table with the codings of both coders and the binary column of agreement.
	- Sheet 2: Calculation of Cohen Kappa and the distribution of the themes.
	- Sheet 3: The codes and descriptions of those.
- `Cohen_kappa_non_adjusted.xlsx`: The initial version of coded responses and Cohen Kappa calculations (before revising the themes and removing "No label" from Cohen Kappa calculations):
	- Sheet 1: A table with the codings of both coders and the binary column of agreement.
	- Sheet 2: Calculation of Cohen Kappa and the distribution of the themes.
	- Sheet 3: The codes and descriptions of those.
- `point_biserial_results_closed_q.csv`: A table showing the results of the calculation of the Point-Biserial coefficients between the closed question data and themes.
- `point_biserial_results_dropout.xlsx`: A table showing the results of the calculation of the Point-Biserial coefficients between the dropout question in session data and themes.
- `point_biserial_results_humanstate.xlsx`: A table showing the results of the calculation of the Point-Biserial coefficients between the state_humansupport question in session data and themes.