"""
For each theme calculates the Point-Biserial correlation coefficient.

Required raw data:
- postquestionnaire responses right joined with data in theme_binary.

The result is printed out into the csv file in Outputs.

Author: Glebs Labunskis
Date: June 2024
"""

import pandas as pd

from point_biserial import calculate_point_biserial

fps = ['../Data/Theme_binary/appreciate.csv', '../Data/Theme_binary/struggle.csv',
             '../Data/Theme_binary/chance.csv', '../Data/Theme_binary/equal.csv']


binary_col = 'theme'

continuous_cols_joined = ['appreciate', 'equal', 'struggle', 'chances']

# Prepare a list to hold the results
results = []

continuous_col_choice = continuous_cols_joined
# Loop over each file and its continuous columns
for fp in fps:

    # Read the data from the CSV file
    data_frame = pd.read_csv(fp)

    # Calculate point-biserial correlation for each continuous column
    for continuous_col in continuous_col_choice:
        try:
            r_pb, p_value = calculate_point_biserial(data_frame, binary_col, continuous_col)
            results.append({
                'file': fp,
                'continuous_col': continuous_col,
                'r_pb': r_pb,
                'p_value': p_value
            })
            print(f"File: {fp}, Continuous Column: {continuous_col}, r_pb: {r_pb}, p_value: {p_value}")
        except Exception as e:
            print(f"Error processing {fp} with column {continuous_col}: {e}")

# Convert the results to a DataFrame
results_df = pd.DataFrame(results)

# Write the results to a CSV file
output_file_path = '../Outputs/point_biserial_results_joined.csv'
results_df.to_csv(output_file_path, index=False, sep=",")

print(f"Results have been written to {output_file_path}")
