"""
Method used to calculate the Point-Biserial coefficient.

Author: Glebs Labunskis
Date: June 2024
"""

from scipy.stats import pointbiserialr


def calculate_point_biserial(data, binary_col, continuous_col):
    """
    Calculate the point-biserial correlation coefficient.
    :param data: pd.DataFrame containing the data
    :param binary_col: string name of the binary variable column
    :param continuous_col: string name of the continuous variable column
    :return: Point-biserial correlation coefficient and p-value
    """
    # Extract the binary and continuous variables
    binary_data = data[binary_col]
    continuous_data = data[continuous_col]

    # Calculate point-biserial correlation using scipy
    r_pb, p_value = pointbiserialr(binary_data, continuous_data)

    return r_pb, p_value
